@@ -13,7 +13,7 @@ test_that("storyURL", {
 })
 
 public({
-    with_mock_API({
+    with_mock_api({
         s <- createStory(name="A test story", story_type="chore")
         test_that("createStory", {
             expect_is(s, "story")
